@@ -1,6 +1,6 @@
 /***************************************************************************
- *   KMidimon - ALSA sequencer based MIDI monitor                          *
- *   Copyright (C) 2005-2010 Pedro Lopez-Cabanillas                        *
+ *   Drumstick MIDI monitor based on the ALSA Sequencer                    *
+ *   Copyright (C) 2005-2023 Pedro Lopez-Cabanillas                        *
  *   plcl@users.sourceforge.net                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -13,23 +13,23 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
- *   MA 02110-1301, USA                                                    *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
+#include <QTextCodec>
+#include <QStyle>
+#include <QStyleFactory>
 #include "configdialog.h"
-#include <KCharsets>
+#include "iconutils.h"
 
 ConfigDialog::ConfigDialog(QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
 {
-    QWidget *widget = new QWidget( this );
-    ui.setupUi(widget);
-    setMainWidget( widget );
-    setCaption( i18nc("@title:window", "KMidimon Configuration") );
-    initEncodings();
+    ui.setupUi(this);
+    IconUtils::SetWindowIcon(this);
+    setWindowTitle(tr("KMidimon Configuration", "@title:window"));
+    initStyles();
 }
 
 bool ConfigDialog::showColumn(int colNum)
@@ -97,21 +97,46 @@ void ConfigDialog::setInstruments( const QStringList& items )
     ui.m_instruments->addItems(items);
 }
 
-void ConfigDialog::initEncodings()
+void ConfigDialog::initStyles()
 {
-    ui.m_codecs->clear();
-    ui.m_codecs->addItem(i18nc("@item:inlistbox Default MIDI text encoding",
-                    "Default ( ASCII )"));
-    ui.m_codecs->addItems( KGlobal::charsets()->descriptiveEncodingNames() );
+    QStringList styleNames = QStyleFactory::keys();
+    ui.m_styles->addItems(styleNames);
+    QString currentStyle = qApp->style()->objectName();
+    foreach(const QString& s, styleNames) {
+        if (QString::compare(s, currentStyle, Qt::CaseInsensitive) == 0) {
+            ui.m_styles->setCurrentText(s);
+            break;
+        }
+    }
 }
 
-QString ConfigDialog::getEncoding()
+QString ConfigDialog::getStyle()
 {
-    return ui.m_codecs->currentText();
+    return ui.m_styles->currentText();
 }
 
-void ConfigDialog::setEncoding(const QString& name)
+void ConfigDialog::setStyle(const QString& name)
 {
-    int index = ui.m_codecs->findText( name );
-    ui.m_codecs->setCurrentIndex( index );
+    int idx = ui.m_styles->findText(name);
+    ui.m_styles->setCurrentIndex(idx);
+}
+
+bool ConfigDialog::getDarkMode()
+{
+    return ui.m_forcedDarkMode->isChecked();
+}
+
+void ConfigDialog::setDarkMode(bool dark)
+{
+    ui.m_forcedDarkMode->setChecked(dark);
+}
+
+bool ConfigDialog::getInternalIcons()
+{
+    return ui.m_forcedTheme->isChecked();
+}
+
+void ConfigDialog::setInternalIcons(bool internal)
+{
+    ui.m_forcedTheme->setChecked(internal);
 }
