@@ -1,6 +1,6 @@
 /***************************************************************************
- *   KMidimon - ALSA sequencer based MIDI monitor                          *
- *   Copyright (C) 2005-2010 Pedro Lopez-Cabanillas                        *
+ *   Drumstick MIDI monitor based on the ALSA Sequencer                    *
+ *   Copyright (C) 2005-2023 Pedro Lopez-Cabanillas                        *
  *   plcl@users.sourceforge.net                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -13,23 +13,21 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
- *   MA 02110-1301, USA                                                    *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
 #ifndef CONFIGDIALOG_H
 #define CONFIGDIALOG_H
 
-#include <KDE/KDialog>
+#include <QDialog>
 #include "ui_configdialogbase.h"
 
-class ConfigDialog : public KDialog
+class ConfigDialog : public QDialog
 {
     Q_OBJECT
 public:
-    ConfigDialog(QWidget *parent = 0);
+    ConfigDialog(QWidget *parent = nullptr);
     virtual ~ConfigDialog() {}
 
     int getTempo() { return ui.m_tempo->value(); }
@@ -74,16 +72,21 @@ public:
     void setInstrumentName(const QString& name);
     void setInstruments(const QStringList& items);
 
-    void initEncodings();
-    QString getEncoding();
-    void setEncoding(const QString& name);
+    void initStyles();
+    QString getStyle();
+    void setStyle(const QString& name);
+
+    bool getDarkMode();
+    void setDarkMode(bool dark);
+
+    bool getInternalIcons();
+    void setInternalIcons(bool internal);
 
     bool requestRealtime() { return ui.m_requestRealtime->isChecked(); }
     void setRequestRealtime(bool newValue) { ui.m_requestRealtime->setChecked(newValue); }
 
     bool resizeColumns() { return ui.m_resizeColumns->isChecked(); }
     void setResizeColumns(bool newValue) { ui.m_resizeColumns->setChecked(newValue); }
-
 private:
     Ui::ConfigDialogBase ui;
 };
