@@ -1,6 +1,6 @@
 /***************************************************************************
- *   KMidimon - ALSA sequencer based MIDI monitor                          *
- *   Copyright (C) 2005-2010 Pedro Lopez-Cabanillas                        *
+ *   Drumstick MIDI monitor based on the ALSA Sequencer                    *
+ *   Copyright (C) 2005-2023 Pedro Lopez-Cabanillas                        *
  *   plcl@users.sourceforge.net                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -13,22 +13,20 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
- *   MA 02110-1301, USA                                                    *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
 #ifndef CONNECTDLG_H
 #define CONNECTDLG_H
 
-#include <kdialog.h>
+#include <QDialog>
 
 class QGroupBox;
-class QStringList;
-class KComboBox;
+class QComboBox;
+class QCheckBox;
 
- class ConnectDlg : public KDialog
+ class ConnectDlg : public QDialog
 {
     Q_OBJECT
 
@@ -42,9 +40,13 @@ class KComboBox;
     QStringList getSelectedInputs() const;
     QString getSelectedOutput() const;
 
+    void setThruEnabled(bool enable);
+    bool isThruEnabled() const;
+
 private:
     QGroupBox* m_group;
-    KComboBox* m_output;
+    QComboBox* m_output;
+    QCheckBox* m_thru;
 };
 
 #endif
