@@ -1,6 +1,6 @@
 /***************************************************************************
- *   KMidimon - ALSA sequencer based MIDI monitor                          *
- *   Copyright (C) 2005-2010 Pedro Lopez-Cabanillas                        *
+ *   Drumstick MIDI monitor based on the ALSA Sequencer                    *
+ *   Copyright (C) 2005-2023 Pedro Lopez-Cabanillas                        *
  *   plcl@users.sourceforge.net                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -13,10 +13,8 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
- *   MA 02110-1301, USA                                                    *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
 #ifndef SEQUENCERADAPTOR_H
@@ -25,15 +23,13 @@
 #include <QEvent>
 #include <QMap>
 
-#include <alsaqueue.h>
-#include <alsaport.h>
-#include <alsaevent.h>
+#include <drumstick/alsaqueue.h>
+#include <drumstick/alsaport.h>
+#include <drumstick/alsaevent.h>
 
 class SequenceModel;
 class Player;
 
-using namespace drumstick;
-
 const int TEMPO_BPM(120);
 const int RESOLUTION(240);
 
@@ -49,6 +45,7 @@ public:
 	    PausedState,
 	    ErrorState
 	};
+    Q_ENUM(State)
 
     SequencerAdaptor(QObject *parent);
     ~SequencerAdaptor();
@@ -90,27 +87,31 @@ public:
     void setRequestRealtime(bool newValue);
     bool requestedRealtime();
 
+    bool isThruEnabled() const;
+    void setThruEnabled(bool enable);
+
 public slots:
     /* handler for the sequencer events */
-    void sequencerEvent( SequencerEvent* ev );
+    void sequencerEvent( drumstick::ALSA::SequencerEvent* ev );
     void songFinished();
+    void shutupChannel(int chan);
     void shutupSound();
-    void setLoop(bool enable);
 
 signals:
     void signalTicks(int tick);
     void finished();
 
 private:
-    QStringList list_ports(PortInfoList& refs);
+    QStringList list_ports(drumstick::ALSA::PortInfoList& refs);
 
     State m_state;
     int m_resolution;
     int m_tempo;
+    bool m_thru;
 
-    MidiClient* m_client;
-    MidiQueue* m_queue;
-    MidiPort* m_port;
+    drumstick::ALSA::MidiClient* m_client;
+    drumstick::ALSA::MidiQueue* m_queue;
+    drumstick::ALSA::MidiPort* m_port;
     SequenceModel* m_model;
     Player* m_player;
 };
